SubscribeConfigurationRequest

Type Alias SubscribeConfigurationRequest 

pub type SubscribeConfigurationRequest = SubscribeConfigurationRequest;
A request for subscribing to configuration changes

Aliased Type

pub struct SubscribeConfigurationRequest {
    pub store_name: String,
    pub keys: Vec<String>,
    pub metadata: HashMap<String, String>,
}

Fields

store_name: String

The name of configuration store.

keys: Vec<String>

Optional. The key of the configuration item to fetch. If set, only query for the specified configuration items. Empty list means fetch all.

metadata: HashMap<String, String>

The metadata which will be sent to configuration store components.